@@ -14,7 +14,7 @@
 #' @return an \code{\link[raster:Extent-class]{Extent}} object
 #' @examples
 #' library(quadtree)
-#' data(habitat)
+#' habitat <- terra::rast(system.file("extdata", "habitat.tif", package="quadtree"))
 #'
 #' # create a quadtree
 #' qt <- quadtree(habitat, split_threshold = .1, adj_type = "expand")
@@ -35,9 +35,9 @@
 setMethod("extent", signature(x = "Quadtree"),
   function(x, original = FALSE) {
     if (original) {
-      return(raster::extent(x@ptr$originalExtent()))
+      return(terra::ext(x@ptr$originalExtent()))
     } else {
-      return(raster::extent(x@ptr$extent()))
+      return(terra::ext(x@ptr$extent()))
     }
   }
 )
