@@ -1,5 +1,5 @@
 test_that("as_data_frame() runs without errors and produces expected output", {
-  data(habitat)
+  habitat <- terra::rast(system.file("extdata", "habitat.tif", package="quadtree"))
   qt <- expect_error(quadtree(habitat, .4), NA)
 
   df_term <- expect_error(as_data_frame(qt, TRUE), NA)
@@ -17,22 +17,24 @@ test_that("as_data_frame() runs without errors and produces expected output", {
 })
 
 test_that("as_raster() works", {
-  data(habitat)
+  habitat <- terra::rast(system.file("extdata", "habitat.tif", package="quadtree"))
   qt <- quadtree(habitat, .1, split_method = "sd")
   rst1 <- expect_error(as_raster(qt), NA)
   rst2 <- expect_error(as_raster(qt, habitat), NA)
-
-  rst_template <- raster::raster(nrows = 189, ncols = 204,
-                                 xmn = 0, xmx = 30000, ymn = 10000, ymx = 45000)
+  rst_template <- terra::rast(nrows = 189, ncols = 204,
+                              xmin = 0, xmax = 30000, ymin = 10000, ymax = 45000)
   rst3 <- expect_error(as_raster(qt, rst_template), NA)
 
-  pts1 <- raster::rasterToPoints(rst1, spatial = FALSE)
-  pts2 <- raster::rasterToPoints(rst2, spatial = FALSE)
-  pts3 <- raster::rasterToPoints(rst3, spatial = FALSE)
+  pts1 <- terra::crds(rst1)
+  pts2 <- terra::crds(rst2)
+  pts3 <- terra::crds(rst3)
 
-  expect_equal(quadtree::extract(qt, pts1[, 1:2]), raster::extract(rst1, pts1[, 1:2]))
-  expect_equal(quadtree::extract(qt, pts2[, 1:2]), raster::extract(rst2, pts2[, 1:2]))
-  expect_equal(quadtree::extract(qt, pts3[, 1:2]), raster::extract(rst3, pts3[, 1:2]))
+  expect_equal(quadtree::extract(qt, pts1), 
+               terra::extract(rst1, pts1)[[1]])
+  expect_equal(quadtree::extract(qt, pts2), 
+               terra::extract(rst2, pts2)[[1]])
+  expect_equal(quadtree::extract(qt, pts3), 
+               terra::extract(rst3, pts3)[[1]])
 })
 
 test_that("as_vector() works", {
@@ -51,8 +53,17 @@ test_that("as_vector() works", {
   expect_equal(sort(as.numeric(mat)), sort(vec_term2))
 })
 
+test_that("foreign object conversion functions run without errors", {
+  habitat <- terra::rast(system.file("extdata", "habitat.tif", package="quadtree"))
+  qt <- quadtree(habitat, .3, split_method = "sd")
+  
+  ch <- expect_error(as(qt, "character"), NA)
+  sf <- expect_error(as(qt, "sf"), NA)
+  v <- expect_error(as(qt, "SpatVector"), NA)
+})
+
 test_that("copy() runs without errors and produces expected output", {
-  data(habitat)
+  habitat <- terra::rast(system.file("extdata", "habitat.tif", package="quadtree"))
   qt1 <- quadtree(habitat, .3, split_method = "sd")
   qt2 <- expect_error(copy(qt1), NA)
   expect_s4_class(qt2, "Quadtree")
@@ -64,23 +75,23 @@ test_that("copy() runs without errors and produces expected output", {
 })
 
 test_that("extent() runs without errors and produces expected output", {
-  #library(raster)
-  data(habitat)
+  # library(terra)
+  habitat <- terra::rast(system.file("extdata", "habitat.tif", package="quadtree"))
   qt1 <- quadtree(habitat, .3, split_method = "sd")
   expect_error(extent(qt1, original = FALSE), NA)
   qt_ext <- expect_error(extent(qt1, original = TRUE), NA)
-  expect_equal(qt_ext, raster::extent(habitat))
+  expect_equal(qt_ext[1:4], terra::ext(habitat)[1:4])
 })
 
 test_that("extract() runs without errors and returns correct values", {
-  # library(raster)
-  data(habitat)
+  # library(terra)
+  habitat <- terra::rast(system.file("extdata", "habitat.tif", package="quadtree"))
   # use 0 to make sure everything gets split as small as possible
   qt1 <- quadtree(habitat, 0)
 
-  ext <- raster::extent(habitat)
+  ext <- terra::ext(habitat)
   pts <- cbind(runif(1000, ext[1], ext[2]), runif(1000, ext[3], ext[4]))
-  rst_ext <- raster::extract(habitat, pts)
+  rst_ext <- terra::extract(habitat, pts)[[1]]
   qt_ext <- expect_error(extract(qt1, pts), NA)
   qt_ext[is.nan(qt_ext)] <- NA
   expect_equal(qt_ext, rst_ext)
@@ -117,7 +128,7 @@ test_that("get_neighbors() works", {
 })
 
 test_that("n_cells() works", {
-  data(habitat)
+  habitat <- terra::rast(system.file("extdata", "habitat.tif", package="quadtree"))
   qt <- quadtree(habitat, .15)
   nc1 <- expect_error(n_cells(qt, TRUE), NA)
   nc2 <- expect_error(n_cells(qt, FALSE), NA)
@@ -127,7 +138,7 @@ test_that("n_cells() works", {
 
 test_that("n_cells(), as_vector(), and as_data_frame() agree on the number of
           nodes", {
-  data(habitat)
+  habitat <- terra::rast(system.file("extdata", "habitat.tif", package="quadtree"))
   qt <- quadtree(habitat, .15)
 
   nc_term <- n_cells(qt, TRUE)
@@ -144,25 +155,26 @@ test_that("n_cells(), as_vector(), and as_data_frame() agree on the number of
 })
 
 test_that("projection() runs without errors and returns correct value", {
-  data(habitat)
-  suppressWarnings({raster::crs(habitat) <- "+init=EPSG:27700"})
+  habitat <- terra::rast(system.file("extdata", "habitat.tif", package="quadtree"))
+  terra::crs(habitat) <- "EPSG:27700"
   qt1 <- quadtree(habitat, .5)
   qt_proj <- expect_error(quadtree::projection(qt1), NA)
-  expect_equal(qt_proj, raster::projection(habitat))
+  expect_equal(qt_proj, terra::crs(terra::rast(habitat)))
 
   expect_error(quadtree::projection(qt1) <- "stuff", NA)
   expect_equal(quadtree::projection(qt1), "stuff")
 })
 
 test_that("read_quadtree() and write_quadtree() work", {
-  data(habitat)
+  habitat <- terra::rast(system.file("extdata", "habitat.tif", package="quadtree"))
   qt1 <- quadtree(habitat, .3, "sd")
   filepath <- tempfile()
   expect_error(write_quadtree(filepath, qt1), NA)
   qt2 <- expect_error(read_quadtree(filepath), NA)
 
   expect_s4_class(qt2, "Quadtree")
-  expect_equal(extent(qt1, original = TRUE), extent(qt2, original = TRUE))
+  expect_equal(extent(qt1, original = TRUE)[1:4], 
+               extent(qt2, original = TRUE)[1:4])
   qt1_nb <- do.call(rbind, qt1@ptr$getNeighborList())
   qt2_nb <- do.call(rbind, qt2@ptr$getNeighborList())
   qt1_nb <- qt1_nb[order(qt1_nb[, "id0"], qt1_nb[, "id1"]), ]
@@ -185,7 +197,7 @@ test_that("read_quadtree() and write_quadtree() work", {
 })
 
 test_that("set_values() works", {
-  data(habitat)
+  habitat <- terra::rast(system.file("extdata", "habitat.tif", package="quadtree"))
   qt <- quadtree(habitat, .2)
   set.seed(10)
   ext <- extent(qt)
@@ -198,7 +210,7 @@ test_that("set_values() works", {
 })
 
 test_that("transform_values() works", {
-  data(habitat)
+  habitat <- terra::rast(system.file("extdata", "habitat.tif", package="quadtree"))
   qt1 <- quadtree(habitat, .1, split_method = "sd")
   qt2 <- copy(qt1)
 
